==> srimaticket_090223_07PM.zip: srimaticket/thank-you.php <==
<?php
    include('header.php');
    $reg_mob = $_SESSION['session_mobile_number'];

    $seat_query = "SELECT * FROM std_ticket WHERE reg_mobile=".$reg_mob; 
	$seat_dt= $mysqli->query($seat_query);		
?>
<div class="auto-container">
    <div class="row">
        <div class="details-pickup-section auto-container">
            <div class="row">
                <div class="col-lg-12 col-md-12 col-12 col-user-profile user-sid">
                    <div class="thank-you-icon">
                        <img src="images/like.svg" alt="">
                    </div>
                    <div class="thank-you-msg">
                        
                        Thank you ! Your seats has been confirmed
                    </div>

                    <ul class="dashboard-data">
                        <li>
                            <a href="">
                                <span>Name</span>
                                <?= $_SESSION['login_name'] ?>
                            </a>
                        </li>
                        <li>
                            <a href="">
                                <span>Email</span>
                                <?= $_SESSION['reg_email'][0] ?>
                            </a>
                        </li>
                        <li>
                            <a href="">
                                <span>Mobile No</span>
                                <?= $_SESSION['session_mobile_number'] ?>
                            </a>
                        </li>
                    </ul>
                    
                    <ul class="dashboard-data">
                        <li class="sid-no">
                            <?php
                                if ($seat_dt->num_rows > 0) {
                                while($row_seat = $seat_dt->fetch_assoc()){                                                            
                            ?>
                            <span>
                                <?= strtoupper($row_seat["seat_type"].'-'.$row_seat["seat_no"]); ?>
                            </span>
                            <?php } } ?>
                        </li>
                    </ul>
                    
                    <div class="qr-code">
                        <img src="images/qr-code.png" alt="">
                    </div>
					
					<div class="col-lg-12">
                        <a target="_blank" href="https://dev.srimaone.in/srimaticket/ticketpdf/<?= $reg_mob.'.pdf' ?>" class="download-tickt">Download PDF</a>
                    </div>
                    
                </div>

            </div>
        </div>
    </div>     
</div>    
<?php
    include('footer.php');
?>

==> srimaticket_100223_02PM.zip: srimaticket/thank-you.php <==
<?php
    include('header.php');
    $reg_mob = $_SESSION['session_mobile_number'];

    $seat_query = "SELECT * FROM std_ticket WHERE reg_mobile=".$reg_mob; 
	$seat_dt= $mysqli->query($seat_query);		
?>
<div class="auto-container">
    <div class="row">
        <div class="details-pickup-section auto-container">
            <div class="row">
                <div class="col-lg-12 col-md-12 col-12 col-user-profile user-sid">
                    <div class="thank-you-icon">
                        <img src="images/like.svg" alt="">
                    </div>
                    <div class="thank-container">
                    <div class="thank-you-msg">
                        
                        Thank you ! Your seats has been confirmed
                    </div>

                    <ul class="dashboard-data">
                        <li>
                            <a href="">
                                <span>Name</span>
                                <?= $_SESSION['login_name'] ?>
                            </a>
                        </li>
                        <li>
                            <a href="">
                                <span>Email</span>
                                <?= $_SESSION['reg_email'][0] ?>
                            </a>
                        </li>
                        <li>
                            <a href="">
                                <span>Mobile No</span>
                                <?= $_SESSION['session_mobile_number'] ?>
                            </a>
                        </li>
                    </ul>
                    
                    <ul class="dashboard-data">
                        <li class="sid-no">
                            <?php
                                if ($seat_dt->num_rows > 0) {
                                while($row_seat = $seat_dt->fetch_assoc()){                                                            
                            ?>
                            <span>
                                <?= strtoupper($row_seat["seat_type"].'-'.$row_seat["seat_no"]); ?>
                            </span>
                            <?php } } ?>
                        </li>
                    </ul>
                    
                    <div class="qr-code">
                        <img src="QRCode/codeimage/<?= $reg_mob.'.png' ?>" alt="">
                    </div>
					
					<div class="col-lg-12">
                        <a target="_blank" href="https://dev.srimaone.in/srimaticket/ticketpdf/<?= $reg_mob.'.pdf' ?>" class="download-tickt">Download PDF</a>
                    </div>
                    </div>
                </div>

            </div>
        </div>
    </div>     
</div>    
<?php
    include('footer.php');
?>
